# Red-Dashboard
*An easy-to-use interactive web dashboard to control your Redbot.*

# Warning
This webserver is in alpha stages.  Please refrain from installing this if you do not believe you can set this up yourself, OR do not wish to provide feedback and bug reports.  To reiterate the announcement on the cog server:

> From here on forward, user issues with installing (for example, not understanding what something is) must be dealt with personally.  I will no longer be helping out with these as I do not have the time for them.  As said before, this cog is in very early stage development, and is not intended for public use, and I am looking for bugs, issues and feedback.  If you cannot understand the (relatively simple) instructions, then now is not a good time to install, and its better to wait until it is officially released.  I would recommend searching google for the answers to your questions.  If for some reason, you cannot understand how to install it at all, and I warn, ONLY if it is that, then you can DM Draper from the Red server.

> However, if you are getting an error with the dashboard (and ONLY if you are getting an error) you may post in #help.  If you have feedback, post in #general.  If you fail to abide to this, no one will help you, and be muted or kicked.

> If you don't like this, uninstall the cog and leave the server.  Its your choice.

## Installation
Still looking to install?  Check out the [documentation](https://red-dashboard.readthedocs.io/en/latest/) to get started.

## Credits
I would like to thank the following, for all the contributions they have made that helped this become what it is today.
* Predeactor, for setting up a huge amount of the documentation.
* Cog Creators, for making such an amazing bot.
* All the people who tested the dashboard, and gave feedback.
* AppSeed, for creating a template that I use as the base for the Dashboard.
